<!DOCTYPE TS><TS>
<context>
    <name>IT8FileSelector</name>
    <message>
        <source>IT8 target:</source>
        <translation type="obsolete">Cible IT8 :</translation>
    </message>
    <message>
        <source>IT8 target</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IT8Selector</name>
    <message>
        <source>Target:</source>
        <translation type="obsolete">Cible :</translation>
    </message>
    <message>
        <source>Target</source>
        <translation type="unfinished">Cible</translation>
    </message>
</context>
<context>
    <name>IT8SelectorWithFileDialog</name>
    <message>
        <source>IT8 Target</source>
        <translation type="unfinished">Cible IT8</translation>
    </message>
</context>
<context>
    <name>InstallRefFileBase</name>
    <message>
        <source>Little CMS Profiler - Install a Reference File</source>
        <translation>Little CMS Profiler - Installe un Fichier Référence</translation>
    </message>
    <message>
        <source>Reference File Installer</source>
        <translation>Installateur de Fichier Référence</translation>
    </message>
    <message>
        <source>template</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <source>*.itx;*.ITX</source>
        <translation type="obsolete">*.itx;*.ITX</translation>
    </message>
    <message>
        <source>Pick template</source>
        <translation>Choisir un modèle</translation>
    </message>
    <message>
        <source>Select a picker template for your target.</source>
        <translation>Choisir un modèle d&apos;extraction pour votre cible.</translation>
    </message>
    <message>
        <source>IT8 Target</source>
        <translation type="obsolete">Cible IT8</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;O.K.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Install the target reference file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not install the target reference file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a target reference file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorValues</name>
    <message>
        <source>D50 (Warm white)</source>
        <translation>D50 (Blanc chaud)</translation>
    </message>
    <message>
        <source>ITU-R BT.709 (sRGB) - DEFAULT</source>
        <translation>ITU-R BT.709 (sRGB) - DEFAUT</translation>
    </message>
    <message>
        <source>SMPTE RP145-1994</source>
        <translation>SMPTE RP145-1994</translation>
    </message>
    <message>
        <source>SMPTE-C (CCIR 601-1)</source>
        <translation>SMPTE-C (CCIR 601-1)</translation>
    </message>
    <message>
        <source>EBU Tech.3213-E</source>
        <translation>EBU Tech.3213-E</translation>
    </message>
    <message>
        <source>EBU [Walker98]</source>
        <translation>EBU [Walker98]</translation>
    </message>
    <message>
        <source>P22</source>
        <translation>P22</translation>
    </message>
    <message>
        <source>NTSC</source>
        <translation>NTSC</translation>
    </message>
    <message>
        <source>HDTV</source>
        <translation>HDTV</translation>
    </message>
    <message>
        <source>CIE</source>
        <translation>CIE</translation>
    </message>
    <message>
        <source>Dell</source>
        <translation>Dell</translation>
    </message>
    <message>
        <source>LCD</source>
        <translation>LCD</translation>
    </message>
    <message>
        <source>Samsung TFT</source>
        <translation>Samsung TFT</translation>
    </message>
    <message>
        <source>Apple RGB</source>
        <translation>Apple RGB</translation>
    </message>
    <message>
        <source>Wide Gamut RGB (700/525/450nm)</source>
        <translation>RGB Gamut élargi (700/525/450nm)</translation>
    </message>
    <message>
        <source>Short persistence [Foley96]</source>
        <translation>Persistence courte [Foley96]</translation>
    </message>
    <message>
        <source>Long persistence  [Foley96]</source>
        <translation>Persistence longue [Foley96]</translation>
    </message>
    <message>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <source>User defined</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <source>D65 (daylight)</source>
        <translation>D65 (Lumière du jour)</translation>
    </message>
    <message>
        <source>D70</source>
        <translation>D70</translation>
    </message>
    <message>
        <source>D75</source>
        <translation>D75</translation>
    </message>
    <message>
        <source>D80</source>
        <translation>D80</translation>
    </message>
    <message>
        <source>D85</source>
        <translation>D85</translation>
    </message>
    <message>
        <source>D90</source>
        <translation>D90</translation>
    </message>
    <message>
        <source>D91</source>
        <translation>D91</translation>
    </message>
    <message>
        <source>D93 - Cold white</source>
        <translation>D93 - Blanc froid</translation>
    </message>
    <message>
        <source>CIE illuminant A</source>
        <translation>CIE illuminant A</translation>
    </message>
    <message>
        <source>CIE illuminant B</source>
        <translation>CIE illuminant B</translation>
    </message>
    <message>
        <source>CIE illuminant C</source>
        <translation>CIE illuminant C</translation>
    </message>
    <message>
        <source>CIE Illuminant E</source>
        <translation>CIE illuminant E</translation>
    </message>
    <message>
        <source>User defined (blackbody locus)</source>
        <translation>Personnalisé ()</translation>
    </message>
</context>
<context>
    <name>MonitorValuesBase</name>
    <message>
        <source>Little CMS Profiler - Monitor Values</source>
        <translation>Little CMS Profiler - Réglages du moniteur</translation>
    </message>
    <message>
        <source>Rough Monitor Values</source>
        <translation>Réglages de moniteur brut</translation>
    </message>
    <message>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <source>2.4</source>
        <translation>2.4</translation>
    </message>
    <message>
        <source>Red or gray Gamma value.</source>
        <translation>Valeur Gamma rouge ou grise</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <source>Green Gamma value.</source>
        <translation>Valeur Gamma verte</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <source>Blue Gamma value.</source>
        <translation>Valeur Gamma bleu</translation>
    </message>
    <message>
        <source>Set Gamma and Black Point</source>
        <translation type="obsolete">Ajustez le gamma et le point noir</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;O.K.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>White point</source>
        <translation>Point blanc</translation>
    </message>
    <message>
        <source>White point:</source>
        <translation>Point blanc:</translation>
    </message>
    <message>
        <source>Select monitor white point. Some monitors refer to this as &apos;temperature&apos;</source>
        <translation>Choisissez le point blanc du moniteur. Quelques moniteurs s&apos;y référe comme &apos;température&apos;</translation>
    </message>
    <message>
        <source>Select monitor white point</source>
        <translation>Choisissez le point blanc du moniteur</translation>
    </message>
    <message>
        <source>K</source>
        <translation>K</translation>
    </message>
    <message>
        <source>To set a White point value that is not one of the presets.</source>
        <translation>Pour configurer une valeur de point blanc différente des valeurs par défaut.</translation>
    </message>
    <message>
        <source>Primaries</source>
        <translation>Primaires</translation>
    </message>
    <message>
        <source>Primaries:</source>
        <translation>Primaires:</translation>
    </message>
    <message>
        <source>Select primaries, if you don&apos;t know what to use, select Rec.709</source>
        <translation>Sélectionnez les primaires, si vous ne savez pas lesquelles utiliser, choisissez Rec.709</translation>
    </message>
    <message>
        <source>y</source>
        <translation>y</translation>
    </message>
    <message>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <source>Accept settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Y Primary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green X Primary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Y Primary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue X Primary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red X primary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Gamma and 
Black Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the Gamma dialog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set &amp;Gamma and Black Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfileChecker</name>
    <message>
        <source>White point near </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown white point </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Perceptual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative colorimetric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Absolute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Estimated gamma:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfileCheckerBase</name>
    <message>
        <source>Little CMS Profiler - Profile Checker</source>
        <translation>Little CMS Profiler - Testeur de profil</translation>
    </message>
    <message>
        <source>Profile Checker</source>
        <translation>Testeur de profil</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>Target and Measurement Data</source>
        <translation>Cible et données de mesure</translation>
    </message>
    <message>
        <source>targets</source>
        <translation type="obsolete">Cibles</translation>
    </message>
    <message>
        <source>*.*</source>
        <translation type="obsolete">*.*</translation>
    </message>
    <message>
        <source>Target</source>
        <translation type="obsolete">Cible</translation>
    </message>
    <message>
        <source>The target reference</source>
        <translation>Cible de référence</translation>
    </message>
    <message>
        <source>(Required) Select the target reference</source>
        <translation>(Requis) Choisissez la cible de référence</translation>
    </message>
    <message>
        <source>Select the file containing device measurement</source>
        <translation>Sélectionnez le fichier contenant le pilote de mesure</translation>
    </message>
    <message>
        <source>(Required) Select the file containing device measurement</source>
        <translation>(Requis) Sélectionnez le fichier contenant le pilote de mesure</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select the sheet containing scanout measurement</source>
        <translation>Sélectionnez la feuille contenant la mesure de sortie scanner</translation>
    </message>
    <message>
        <source>Measurement:</source>
        <translation>Mesure:</translation>
    </message>
    <message>
        <source>This is the message console</source>
        <translation>Ceci est la console de message</translation>
    </message>
    <message>
        <source>CIE diagram</source>
        <translation>Diagramme CIE </translation>
    </message>
    <message>
        <source>CIE diagram for the profile.</source>
        <translation>Diagramme CIE pour le profil.</translation>
    </message>
    <message>
        <source>dE report</source>
        <translation>dE report</translation>
    </message>
    <message>
        <source>These are the results</source>
        <translation type="obsolete">Voici les résultats</translation>
    </message>
    <message>
        <source>Delta E report.  Details for each patch on the target.</source>
        <translation>Rapport Delta E. Details pour chaque échantillon sur la cible</translation>
    </message>
    <message>
        <source>Curves</source>
        <translation>Courbes</translation>
    </message>
    <message>
        <source>LUT prelinearization (AToB)</source>
        <translation>prelinearisation LUT (AversB)</translation>
    </message>
    <message>
        <source>LUT prelinearization (BToA)</source>
        <translation>prelinearisation LUT (BversA)</translation>
    </message>
    <message>
        <source>LUT postlinearization (BToA)</source>
        <translation>postlinearisation LUT (BversA)</translation>
    </message>
    <message>
        <source>LUT postlinearization (AToB)</source>
        <translation>postlinearisation LUT (AversB)</translation>
    </message>
    <message>
        <source>Shaper TRC</source>
        <translation>Formeur TRC</translation>
    </message>
    <message>
        <source>Monitor profile</source>
        <translation>Profil moniteur</translation>
    </message>
    <message>
        <source>Profile:</source>
        <translation>Profil:</translation>
    </message>
    <message>
        <source>Filename of the profile being inspected.</source>
        <translation>Nom de fichier du profil à inspecter.</translation>
    </message>
    <message>
        <source>(Required) name of file of the profile you are inspecting.</source>
        <translation>(Requis) Nom du profil que vous inspectez.</translation>
    </message>
    <message>
        <source>(Required) name of file to save the profile</source>
        <translation>(Requis) Nom de fichier pour sauvegarde du profil.</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <source>&amp;Inspect Profile</source>
        <translation>&amp;Inspecter le profil</translation>
    </message>
    <message>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <source>Message from the inpection process are displayed here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Profile statisics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B to A prelinearization curve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A to B prelinearization curve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A to B postlinearization curve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gamma correction curve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B to A postlinearization curve</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display CLUT curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press this button to run the inspection routines.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfileIDBase</name>
    <message>
        <source>Little CMS Profiler</source>
        <translation>Little CMS Profiler</translation>
    </message>
    <message>
        <source>Profile Information</source>
        <translation>Information de profil</translation>
    </message>
    <message>
        <source>Profile identification</source>
        <translation>Identification de profil</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Description:</translation>
    </message>
    <message>
        <source>Manufacturer:</source>
        <translation>Constructeur:</translation>
    </message>
    <message>
        <source>Model :</source>
        <translation>Modele:</translation>
    </message>
    <message>
        <source>Copyright:</source>
        <translation>Copyright:</translation>
    </message>
    <message>
        <source>Comments:</source>
        <translation>Commentaires:</translation>
    </message>
    <message>
        <source>Device Model</source>
        <translation>Modele</translation>
    </message>
    <message>
        <source>Fill it with your device model.</source>
        <translation>Remplacer avec votre modele de périphérique.</translation>
    </message>
    <message>
        <source>Manufacturer of the device.</source>
        <translation>Constructeur du périphérique.</translation>
    </message>
    <message>
        <source>a small description</source>
        <translation>une petite description</translation>
    </message>
    <message>
        <source>Any comments to place in your profile?</source>
        <translation>Des commentaires à ajouter à votre profil?</translation>
    </message>
    <message>
        <source>copyright notice</source>
        <translation>Notice de copyright</translation>
    </message>
    <message>
        <source>YES! you can put your own copyright too! </source>
        <translation>OUI! Vous pouvez aussi ajouter votre copyright!</translation>
    </message>
    <message>
        <source>optional comments</source>
        <translation>Commentaires optionnels</translation>
    </message>
    <message>
        <source>Be creative!</source>
        <translation>Soyez créatifs!</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;O.K.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Device/profile description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device Manufacturer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Added comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept the profile information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProfileParms</name>
    <message>
        <source>(%g) Smoothness:</source>
        <translation type="unfinished">(%g) Douceur:</translation>
    </message>
    <message>
        <source>(%g) Avg. Deviation:</source>
        <translation type="unfinished">(%g) Déviation approximative:</translation>
    </message>
</context>
<context>
    <name>ProfileParmsBase</name>
    <message>
        <source>Little CMS Profiler - Profile Parameters</source>
        <translation>Little CMS Profiler - Parametres de profil </translation>
    </message>
    <message>
        <source>Profile Parameters and Tweaks</source>
        <translation>Paramétres de profil et tweaks</translation>
    </message>
    <message>
        <source>Resolution (CLUT points)</source>
        <translation>Résolution (Point CLUT)</translation>
    </message>
    <message>
        <source>Compromise size/quality</source>
        <translation>Compromis taille/qualité</translation>
    </message>
    <message>
        <source>20 - large</source>
        <translation>20 - large</translation>
    </message>
    <message>
        <source>For best profiles, where space in not a concern.</source>
        <translation>Pour les meilleurs profils, dans lesquels l&apos;espace n&apos;est pas un problème</translation>
    </message>
    <message>
        <source>10 - embedding</source>
        <translation>10 - incorporer</translation>
    </message>
    <message>
        <source>Small but accurate enough for most uses.</source>
        <translation>Petit mais suffisamment précis pour la plupart des usages</translation>
    </message>
    <message>
        <source>16 - small</source>
        <translation>16 - petit</translation>
    </message>
    <message>
        <source>Wise choice, small  and accurate</source>
        <translation>Choix sage, petit et approximatif</translation>
    </message>
    <message>
        <source>33 - huge</source>
        <translation>33 - énorme</translation>
    </message>
    <message>
        <source>For the very best profiles, very large but highest accuracy.</source>
        <translation>Pour les meilleurs des profils, très large mais de la meilleure précision</translation>
    </message>
    <message>
        <source>Profile verbosity</source>
        <translation>Verbosité du profil</translation>
    </message>
    <message>
        <source>Tags included in profile</source>
        <translation>Balises incluses dans le profil</translation>
    </message>
    <message>
        <source>Only required tags</source>
        <translation>Seulement les balises requises</translation>
    </message>
    <message>
        <source>Absolute minimum tags needed </source>
        <translation>Seulement les balises absolument nécessaires</translation>
    </message>
    <message>
        <source>Store additional tags</source>
        <translation>Mettre des balises additionnelles</translation>
    </message>
    <message>
        <source>Verbose, store anything</source>
        <translation>Verbose, tout ajouter</translation>
    </message>
    <message>
        <source>Store all known tags</source>
        <translation>Ajouter toutes les balises connues</translation>
    </message>
    <message>
        <source>Regression Parameters</source>
        <translation>Paramètre de régression</translation>
    </message>
    <message>
        <source>Avg. Deviation:</source>
        <translation>Déviation approximative:</translation>
    </message>
    <message>
        <source>Smoothness:</source>
        <translation>douceur:</translation>
    </message>
    <message>
        <source>Chromatic adaptation &amp;&amp; viewing condition</source>
        <translation>Adaptation chromatique et condition de visualisation</translation>
    </message>
    <message>
        <source>Several adjustments for chromatic adaptation (viewing conditions).</source>
        <translation>Plusieurs ajustements pour l&apos;adaptation chromatique (conditions de visualisation).</translation>
    </message>
    <message>
        <source>Linear Bradford - set this one to promote icc compatibility</source>
        <translation>Bradford linéaire - à utiliser pour améliorer la compatibilité icc</translation>
    </message>
    <message>
        <source>Use Bradford chromatic adaptation</source>
        <translation>Utiliser l&apos;adaptation chromatic Bradford</translation>
    </message>
    <message>
        <source>CIECAM97s - set this one to improve color appearance </source>
        <translation>CIECAM97s - à utiliser pour améliorer l&apos;apparence de la couleur</translation>
    </message>
    <message>
        <source>Use CIECAM97s color appearance model</source>
        <translation>Utilisez le modele de couleur CIECAM97s</translation>
    </message>
    <message>
        <source>Background relative luminance.  Use to adjust brigthness of profile.</source>
        <translation>Luminance relative du fond. Utiliser pour ajuster la clarté du profil.</translation>
    </message>
    <message>
        <source>Emulated surround:</source>
        <translation>environnement émulé:</translation>
    </message>
    <message>
        <source>Average surround (&gt; 4)</source>
        <translation>Environnement moyen (&gt;4)</translation>
    </message>
    <message>
        <source>Average surround</source>
        <translation>Environnement moyen</translation>
    </message>
    <message>
        <source>Dim surround</source>
        <translation>Environnement léger</translation>
    </message>
    <message>
        <source>Dark surround</source>
        <translation>Environnement sombre</translation>
    </message>
    <message>
        <source>Cutsheet surround</source>
        <translation>Cutsheet surround</translation>
    </message>
    <message>
        <source>Emulated surrond types</source>
        <translation>Types d&apos;environnements émulés</translation>
    </message>
    <message>
        <source>Yb:</source>
        <translation>Yb:</translation>
    </message>
    <message>
        <source>Background relative luminance</source>
        <translation>Luminance relative de fond</translation>
    </message>
    <message>
        <source>La:</source>
        <translation>La:</translation>
    </message>
    <message>
        <source>Adapting field in cd/m2</source>
        <translation>Adaptation du champ en cd/m2</translation>
    </message>
    <message>
        <source>Adapting field in cd/m2.  Use to adjust brigthness of profile.</source>
        <translation>Adaptation du champ en cd/m2. Utiliser pour ajuster la clarté du profil.</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;O.K.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Set the resolution of the Color Look Up Table.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parameters used to control the fit of the CLUT curves to the measurement data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Regression parameters for fitting the profile curves to the measurement data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Higher values result in smoother CLUT curves.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Regression smoothness parameter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the Avg. Deviation regression parameter.  Lower values result in a closer fit of the curve to the measurement data points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower values result in the curves having a better fit to the measurement data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How dark or light the viewing background is.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept Profile parameter values.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTranslator</name>
    <message>
        <source>(*) Perceptual</source>
        <translation type="obsolete">(*) Perceptif</translation>
    </message>
    <message>
        <source>(*) Relative colorimetric</source>
        <translation type="obsolete">(*) Colorimétrie relative</translation>
    </message>
    <message>
        <source>(*) Saturation</source>
        <translation type="obsolete">(*) Saturation</translation>
    </message>
    <message>
        <source>(*) Absolute</source>
        <translation type="obsolete">(*) Absolu</translation>
    </message>
    <message>
        <source>

Select the  profile to check. Optionally, you can select target reference and measurement for dE testing.

Press &apos;Inspect Profile&apos; when done.</source>
        <translation>Sélectionnez le profil à tester. Optionnellement, vous pouvez sélectionner une cible référence et une mesure pour le test dE. 

Appuyez ensuite sur &apos;Inspecter le profil&apos;.</translation>
    </message>
    <message>
        <source> Select target vendor &amp;&amp; type </source>
        <translation type="obsolete">Sélectionnez la cible vendeur &amp;&amp; le type</translation>
    </message>
    <message>
        <source>
Profile: </source>
        <translation>Profil:</translation>
    </message>
    <message>
        <source>
Media white (XYZ): %3.2f, %3.2f, %3.2f</source>
        <translation type="obsolete">
Blanc moyen (XYZ): %3.2f, %3.2f, %3.2f</translation>
    </message>
    <message>
        <source>Primaries: R:%1.2g, %1.2g  G:%1.2g, %1.2g  B:%1.2g, %1.2g</source>
        <translation type="obsolete">Primaires: R:%1.2g, %1.2g  G:%1.2g, %1.2g  B:%1.2g, %1.2g</translation>
    </message>
    <message>
        <source>Estimated gamma : R:%1.3g, G:%1.3g  B:%1.3g</source>
        <translation type="obsolete">Gamma estimé : R:%1.3g, G:%1.3g  B:%1.3g</translation>
    </message>
    <message>
        <source>icc profiles (*.icc *.icm)
All files (*.*)</source>
        <translation>profil icc (*.icc *.icm)
Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Select profile filename</source>
        <translation>Sélectionnez le nom de fichier du profil</translation>
    </message>
    <message>
        <source>IT8/CGATS.5 Files (*.it? *.cgt)
All files (*.*)</source>
        <translation>Fichiers IT8/CGATS.5 (*.it? *.cgt)
Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Select measurement filename</source>
        <translation>Sélectionnez le nom de fichier de la mesure</translation>
    </message>
    <message>
        <source>Select </source>
        <translation>Choisir</translation>
    </message>
    <message>
        <source> directory</source>
        <translation>répertoire</translation>
    </message>
    <message>
        <source>CIE La*b* dE</source>
        <translation>CIE La*b* dE</translation>
    </message>
    <message>
        <source>Target error</source>
        <translation>Erreur de cible</translation>
    </message>
    <message>
        <source>Chroma error</source>
        <translation>Erreur chroma</translation>
    </message>
    <message>
        <source>Hue error</source>
        <translation>Erreur de teinte</translation>
    </message>
    <message>
        <source>Luma error</source>
        <translation>Erreur de Luminosité</translation>
    </message>
    <message>
        <source>Target Lab</source>
        <translation> Cible Lab</translation>
    </message>
    <message>
        <source>Got</source>
        <translation>Resultat</translation>
    </message>
    <message>
        <source>dE CIE94</source>
        <translation>dE CIE94</translation>
    </message>
    <message>
        <source>dE CMC</source>
        <translation>dE CMC</translation>
    </message>
    <message>
        <source>dE BFL</source>
        <translation>dE BFL</translation>
    </message>
    <message>
        <source>(achromatic)</source>
        <translation>(achromatique)</translation>
    </message>
    <message>
        <source>Load image failure</source>
        <translation type="obsolete">Charger l&apos;erreur d&apos;image</translation>
    </message>
    <message>
        <source>This image format is unsupported by LPROF
on your system. Sorry. Supported ones 
are BMP, GIF, JPEG, PNG, PBM, PGM,
PNM, PPM, SUN, TIFF and VIFF.</source>
        <translation type="obsolete">Ce format d&apos;image n&apos;est pas supporté par LPROF
sur votre système. Désolé. Les formats supportés sont :  BMP, GIF, JPEG, PNG, PBM, PGM,
PNM, PPM, SUN, TIFF and VIFF.</translation>
    </message>
    <message>
        <source>This image is not a color RGB image.
Only color images are supported at this time.</source>
        <translation type="obsolete">Cette image n&apos;est pas en couleur RGB. Seules les images couleurs sont supportées actuellement.</translation>
    </message>
    <message>
        <source>(%g) La:</source>
        <translation type="obsolete">(%g) La:</translation>
    </message>
    <message>
        <source>(%g) Yb:</source>
        <translation type="obsolete">(%g) Yb:</translation>
    </message>
    <message>
        <source>(%g) Smoothness:</source>
        <translation type="obsolete">(%g) Douceur:</translation>
    </message>
    <message>
        <source>(%g) Avg. Deviation:</source>
        <translation type="obsolete">(%g) Déviation approximative:</translation>
    </message>
    <message>
        <source>&lt;qt&gt;&lt;font size=4&gt;&lt;table cellspacing=0 cellpadding=0&gt;   &lt;tr&gt;     &lt;td align=right&gt;&lt;b&gt;&lt;font color=red&gt;Average dE :&lt;/font&gt;&lt;/b&gt;&lt;/td&gt;    &lt;td&gt;&lt;b&gt;&lt;u&gt;%1&lt;/b&gt;&lt;/u&gt;&lt;/td&gt;    &lt;td align=right&gt;&lt;font color=blue&gt;Standard deviation :&lt;/font&gt;&lt;/td&gt;    &lt;td&gt;%2&lt;/td&gt;  &lt;/tr&gt;  &lt;tr&gt;    &lt;td align=right&gt;Peak :&lt;/td&gt;     &lt;td&gt;%3&lt;/td&gt;   &lt;/tr&gt;   &lt;tr&gt;     &lt;td align=right&gt;Min : &lt;/td&gt;     &lt;td&gt;%4&lt;/td&gt;   &lt;/tr&gt; </source>
        <translation>&lt;qt&gt;&lt;font size=4&gt;&lt;table cellspacing=0 cellpadding=0&gt;   &lt;tr&gt;     &lt;td align=right&gt;&lt;b&gt;&lt;font color=red&gt; dE moyen :&lt;/font&gt;&lt;/b&gt;&lt;/td&gt;    &lt;td&gt;&lt;b&gt;&lt;u&gt;%1&lt;/b&gt;&lt;/u&gt;&lt;/td&gt;    &lt;td align=right&gt;&lt;font color=blue&gt;Deviation standard :&lt;/font&gt;&lt;/td&gt;    &lt;td&gt;%2&lt;/td&gt;  &lt;/tr&gt;  &lt;tr&gt;    &lt;td align=right&gt;Sommet :&lt;/td&gt;     &lt;td&gt;%3&lt;/td&gt;   &lt;/tr&gt;   &lt;tr&gt;     &lt;td align=right&gt;Min : &lt;/td&gt;     &lt;td&gt;%4&lt;/td&gt;   &lt;/tr&gt; </translation>
    </message>
    <message>
        <source>  &lt;tr&gt;     &lt;td align=right&gt;Average Target error: (99%% confidence)&lt;/td&gt;     &lt;td&gt;%1&lt;/td&gt;     &lt;td align=right&gt;&lt;font color=blue&gt;Maximum error induced by target itself:&lt;font&gt;&lt;/i&gt;&lt;/td&gt;     &lt;td&gt;%2&lt;/td&gt;   &lt;/tr&gt; </source>
        <translation>  &lt;tr&gt;     &lt;td align=right&gt;moyenne d&apos;erreur de cible: (99%% confiance)&lt;/td&gt;     &lt;td&gt;%1&lt;/td&gt;     &lt;td align=right&gt;&lt;font color=blue&gt;Taux maximal d&apos;erreurs induites par la cible elle-même :&lt;font&gt;&lt;/i&gt;&lt;/td&gt;     &lt;td&gt;%2&lt;/td&gt;   &lt;/tr&gt; </translation>
    </message>
</context>
<context>
    <name>SetGammaBase</name>
    <message>
        <source>Little CMS Profiler - set gamma and black point</source>
        <translation>Little CMS Profiler - paramétrer le gamma et le point noir</translation>
    </message>
    <message>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <source>Move the slider until shading across chart is most even.</source>
        <translation>Déplacer la glissière jusqu&apos;à ce que la partie sombre du graphique soit plus ressemblante.</translation>
    </message>
    <message>
        <source>Move the slider until color is most even.</source>
        <translation>Déplacer la glissière jusqu&apos;à ce que la couleur soit plus claire.</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>Select to set red Gamma.</source>
        <translation>A choisir pour paramètrer le gamma rouge.</translation>
    </message>
    <message>
        <source>G</source>
        <translation>G</translation>
    </message>
    <message>
        <source>Select to set green Gamma.</source>
        <translation>A choisir, pour paramètrer le gamma vert.</translation>
    </message>
    <message>
        <source>2.4</source>
        <translation>2.4</translation>
    </message>
    <message>
        <source>Green Gamma value.</source>
        <translation>Valeur de Gamma vert.</translation>
    </message>
    <message>
        <source>Red or gray Gamma value.</source>
        <translation>Valeur de Gamma rouge ou gris.</translation>
    </message>
    <message>
        <source>Blue Gamma value.</source>
        <translation>Valeur de Gamma Bleu.</translation>
    </message>
    <message>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <source>Select to set blue Gamma.</source>
        <translation>A choisir, pour paramètrer le gamma bleu.</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>Link channels</source>
        <translation>Lier les canaux</translation>
    </message>
    <message>
        <source>If checked RGB channels will all be set to the same gamma.</source>
        <translation>Si les canaux RVB sont cochés, ils prendront tous le même gamma.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;O.K.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>To set gamma use the above chart.  When set to have the most even color 
your display will have a gamma of 2.2.   

Use the chart to the right to assist in setting the monitor black point (use the 
brightness control on the monitors).  On the right sideof this chart there are 
two lighter vertical bars.   Bar A should be just visible opposite where gamma 
= 2.2 on the left side of the chart. It should no longer be visible by gamma = 
1.9.  Bar B should be lighter than bar A but still very dark.

These charts are used with permission from Norman Koren.  For more 
information see:

http://www.normankoren.com/makingfineprints1A.html#gammachar</source>
        <translation>Gamma Gebrauch einstellen das oben genannte Diagramm. Wenn der Satz, um 
die gleichmäßigste Farbe zu haben Ihre Anzeige ein Gamma von 2.2 hat. 

Benutzen Sie das Diagramm rechts, in der Einstellung des Monitorschwarzpunktes 
zu unterstützen (verwenden Sie die Helligkeitseinstellung auf den Monitoren). Auf 
dem rechten sideof sind dieses Diagramm dort zwei hellere senkrechte Striche. 
Halten Sie A sollte sein gerade sichtbar gegenüber von wo Gamma = 2.2 auf der 
linken Seite des Diagramms ab. Es sollte durch Gamma sichtbar nicht mehr 
sein = 1.9., die Stab B heller als abhalten A aber noch sehr dunkel sein sollte. 

Diese Diagramme werden mit Erlaubnis von normannischem Koren benutzt. 
Zu mehr Information sehen Sie: 

http://www.normankoren.com/makingfineprints1A.html#gammachar</translation>
    </message>
    <message>
        <source>Update Gamma values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large gamma chart make the area across from 2.2 as even as possible in color.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <source></source>
        <comment>displayed in the messages widget</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>White</name>
    <message>
        <source></source>
        <comment>point text for Profile Checker information screen</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>lprofMain</name>
    <message>
        <source>Image files (*.gif *.png *.jpg *.bmp *.pbm *.pgm *.pnm *.sun *.tif *.tiff *.viff *.GIF *.PNG *.JPG *.BMP *.PBM *.PGM *.PNM *.SUN *.TIF *.TIFF *.VIFF)
All files (*.*)</source>
        <translation type="obsolete">Fichiers Image (*.gif *.png *.jpg *.bmp *.pbm *.pgm *.pnm *.sun *.tif *.tiff *.viff *.GIF *.PNG *.JPG *.BMP *.PBM *.PGM *.PNM *.SUN *.TIF *.TIFF *.VIFF)
Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Select target image</source>
        <translation type="obsolete">Choisissez une image cible</translation>
    </message>
    <message>
        <source>Profiling... please wait</source>
        <translation type="obsolete">Profil en cours... patientez</translation>
    </message>
    <message>
        <source>Working hard...</source>
        <translation>Travaille ardemment...</translation>
    </message>
    <message>
        <source>** ERROR: Unable to profile.</source>
        <translation>** ERREUR : Impossible de profiler.</translation>
    </message>
    <message>
        <source>Ready to GO!</source>
        <translation type="obsolete">Prêt !</translation>
    </message>
    <message>
        <source>icc profiles (*.icc *.icm)
All files (*.*)</source>
        <translation type="obsolete">profils ICC (*.icc *.icm)
Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Select output profile filename</source>
        <translation type="obsolete">Choisissez une nom de profil en sortie</translation>
    </message>
    <message>
        <source>select file name</source>
        <translation>Choissez un nom de fichier</translation>
    </message>
    <message>
        <source>You still have to select the target reference file</source>
        <translation type="obsolete">Vous devez encore sélectionner le fichier cible de référence</translation>
    </message>
    <message>
        <source>You need to specify output profile!</source>
        <translation type="obsolete">Vous devez spécifier un profil de sortie!</translation>
    </message>
    <message>
        <source>You need to load a target image and select it&apos;s corners!</source>
        <translation type="obsolete">Vous devez charger une image cible et sélectionner ses angles! </translation>
    </message>
    <message>
        <source>You need to enter monitor values.</source>
        <translation type="obsolete">Vous devez entrer les valeurs du moniteur.</translation>
    </message>
    <message>
        <source>You need to specify a measurement sheet!</source>
        <translation type="obsolete">Vous devez spécifier une feuille de mesure!</translation>
    </message>
    <message>
        <source>Profile verbosity: Only required tags</source>
        <translation>Verbosité de profil : seulement les tags requis</translation>
    </message>
    <message>
        <source>Profile verbosity: Store additional tags</source>
        <translation>Verbosité de Profil : Place les tags additionnels</translation>
    </message>
    <message>
        <source>Profile verbosity: Store anything</source>
        <translation>Verbosité de profil : enregistre tout</translation>
    </message>
    <message>
        <source>Regression:</source>
        <translation>Regression :</translation>
    </message>
    <message>
        <source>    Smoothness: %g</source>
        <translation type="obsolete">    Douceur: %g</translation>
    </message>
    <message>
        <source>    Deviation: %g</source>
        <translation type="obsolete">    Deviation: %g</translation>
    </message>
    <message>
        <source>CIECAM97s: </source>
        <translation>CIECAM97s: </translation>
    </message>
    <message>
        <source>     Average surround (&gt;4)</source>
        <translation>     Average surround (&gt;4)</translation>
    </message>
    <message>
        <source>     Average surround</source>
        <translation>     Average surround</translation>
    </message>
    <message>
        <source>     Dim surround</source>
        <translation>     Dim surround </translation>
    </message>
    <message>
        <source>     Dark surround</source>
        <translation>     Dark surround</translation>
    </message>
    <message>
        <source>     Cutsheet surround</source>
        <translation>     Cutsheet surround</translation>
    </message>
    <message>
        <source>     La: %g</source>
        <translation type="obsolete">     La: %g</translation>
    </message>
    <message>
        <source>     Yb: %g</source>
        <translation type="obsolete">     Yb: %g</translation>
    </message>
    <message>
        <source>Linear Bradford </source>
        <translation>Bradford linéaire</translation>
    </message>
    <message>
        <source>Model: </source>
        <translation>Modèle: </translation>
    </message>
    <message>
        <source>Manufacturer: </source>
        <translation>Constructeur: </translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Description: </translation>
    </message>
    <message>
        <source>Copyright: </source>
        <translation>Copyright: </translation>
    </message>
    <message>
        <source>Resolution (CLUT points):  </source>
        <translation type="obsolete">Résolution (Point CLUT):  </translation>
    </message>
    <message>
        <source>*** WARNING: Inconsistences found, profile may be wrong. Check the target!</source>
        <translation>*** ATTENTION: Inconsistences trouvées, Le profil peut être défectueux. Essayez avec la cible!</translation>
    </message>
    <message>
        <source>Loading sheets...</source>
        <translation>Charge les feuilles...</translation>
    </message>
    <message>
        <source>Reference sheet: %1</source>
        <translation>Feuille de Référence: %1</translation>
    </message>
    <message>
        <source>Measurement sheet: %1</source>
        <translation>Feuille de mesure: %1</translation>
    </message>
    <message>
        <source>Primaries: R:%1, %2  G:%3, %4  B:%5, %6</source>
        <translation>Primaires: R:%1, %2  V:%3, %4  B:%5, %6</translation>
    </message>
    <message>
        <source>Primaries (x-y): [Red: %1, %2] [Green: %3, %4] [Blue: %5, %6]</source>
        <translation>Primaires (x-y): [Rouge: %1, %2] [Vert: %3, %4] [Bleu: %5, %6]</translation>
    </message>
    <message>
        <source>Gamut hull: %1 inside, %2 outside, %3 on boundaries</source>
        <translation>Limite de Gamut: %1 Intérieur, %2 Extérieur, %3 Précise</translation>
    </message>
    <message>
        <source>Estimated gamma: [Red: %1] [Green: %2] [Blue: %3]</source>
        <translation>Gamma estimé : [Rouge: %1] [Vert: %2] [Bleu: %3]</translation>
    </message>
    <message>
        <source>I have choosen Lab as PCS</source>
        <translation type="obsolete">J&apos;ai choisi  Lab comme PCS</translation>
    </message>
    <message>
        <source>I have choosen XYZ as PCS</source>
        <translation type="obsolete">J&apos;ai choisi XYZ comme PCS</translation>
    </message>
    <message>
        <source>Profile &apos;%1&apos; DONE!</source>
        <translation>Profil &apos;%1&apos; accompli!</translation>
    </message>
    <message>
        <source>I have choosen CIE Lab as PCS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I have choosen CIE XYZ as PCS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White point near %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown white point %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fitting error (delta E CIELAB): mean=%1, RMS=%2, 95%%=%3, median=%4, MAD=%5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fitting error (delta E CIE94): mean=%1, RMS=%2, 95%%=%3, median=%4, MAD=%5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution (CLUT points)</source>
        <translation type="unfinished">Résolution (Point CLUT)</translation>
    </message>
    <message>
        <source>Smoothness:</source>
        <translation type="unfinished">douceur:</translation>
    </message>
    <message>
        <source>Deviation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>     La:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>     Yb:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>lprofMainBase</name>
    <message>
        <source>Little CMS Profiler</source>
        <translation>Profileur LittleCMS</translation>
    </message>
    <message>
        <source>LCMS Profiler</source>
        <translation>Profileur LCMS</translation>
    </message>
    <message>
        <source>Profile Identification</source>
        <translation>Identification de Profil</translation>
    </message>
    <message>
        <source>Press this to change profile identification information.</source>
        <translation>Cliquez ici pour changer les informations d&apos;identification de profil.</translation>
    </message>
    <message>
        <source>Profile indentification information that will be included in the profile tags..</source>
        <translation>Information d&apos;identification de profil qui seront incluses dans les tags du profil.</translation>
    </message>
    <message>
        <source>Profile indentification information that will be included in the profile tags.</source>
        <translation>Information d&apos;identification de profil qui seront incluses dans les tags du profil.</translation>
    </message>
    <message>
        <source>Profile Parameters</source>
        <translation>Paramétres de profil</translation>
    </message>
    <message>
        <source>Press this to change profile parameters.</source>
        <translation>Cliquez ici pour changer les paramètres de profil.</translation>
    </message>
    <message>
        <source>Profile parameter information.  This will affect how the profile is created.</source>
        <translation>Information de paramètre de profil. Cela va affecter la façon dont le profil sera créé.</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <source>This is the profiler message console</source>
        <translation>Ceci est la console de message du profileur</translation>
    </message>
    <message>
        <source>Camera/Scanner Profiler</source>
        <translation>Profileur Appareil Photo/Scanner</translation>
    </message>
    <message>
        <source>IT8 Target</source>
        <translation>Cible IT8</translation>
    </message>
    <message>
        <source>Load Image</source>
        <translation>Charge image</translation>
    </message>
    <message>
        <source>Load IT8.7 target image then select target corners.</source>
        <translation>Chargez une image cible IT8.7 puis choisissez les angles de la cible.</translation>
    </message>
    <message>
        <source>Select the target image to be used to make the measurements used to create the profile.</source>
        <translation>Choisissez l&apos;image cible à utiliser pour faire des mesures utilisables pour créer le profil.</translation>
    </message>
    <message>
        <source>Output Profile File:</source>
        <translation>Fichier Profil de sortie:</translation>
    </message>
    <message>
        <source>Please enter or select an output file for the profile.</source>
        <translation>Entrez ou choisissez un fichier de sortie pour votre profil.</translation>
    </message>
    <message>
        <source>Profile output file name.</source>
        <translation>Nom de fichier de sortie pour le profil.</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Create Profile</source>
        <translation>Créer le profil</translation>
    </message>
    <message>
        <source>To create a profile press this.</source>
        <translation>Pour créer un profil, cliquez ici.</translation>
    </message>
    <message>
        <source>Button to create a profile.</source>
        <translation>Bouton pour créer un profil.</translation>
    </message>
    <message>
        <source>Profile Checker</source>
        <translation>Controleur de profil</translation>
    </message>
    <message>
        <source>Push to bring up the profile checker.</source>
        <translation>Pousser pour ouvrir le controleur de profil.</translation>
    </message>
    <message>
        <source>Run the profile checker.</source>
        <translation>Lancer le controleur de profil.</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Monitor Profiler</source>
        <translation>Profil Moniteur</translation>
    </message>
    <message>
        <source>Select the way you want to profile your monitor and the resulting profile filename. Press Create Profile to start profiling.</source>
        <translation>Choisissez la façon de profiler votre moniteur et le nom de fichier du profil résultant. Pressez Créer Profil pour commencer la création du profil.</translation>
    </message>
    <message>
        <source>(Required) name of file to save the profile</source>
        <translation>(Requis) nom du fichier pour enregistrer le profil</translation>
    </message>
    <message>
        <source>Profiling method</source>
        <translation>Méthode de profilage</translation>
    </message>
    <message>
        <source>Compromise size/quality</source>
        <translation type="obsolete">Compromis Taille/qualité</translation>
    </message>
    <message>
        <source>I want to build a coarse profile, giving approximate values</source>
        <translation>Je veux construire un profil  en donnant des valeur approximatives</translation>
    </message>
    <message>
        <source>To create monitor profile when you do not have hardware to measure monitor characteristics.</source>
        <translation>Pour créer un profil moniteur quand vous n&apos;avez pas de matériel pour mesurer les caractéristiques du moniteur.</translation>
    </message>
    <message>
        <source>No special hardware is required by using this method.</source>
        <translation>Aucun matériel n&apos;est requis dans cette méthode.</translation>
    </message>
    <message>
        <source>Enter monitor values &gt;&gt;</source>
        <translation>Entrez les valeurs du moniteur &gt;&gt;</translation>
    </message>
    <message>
        <source>Start dialog to set parameters to be used for profiling monitor.</source>
        <translation>Fenêtre initiale pour les paramétres à utiliser pour le profilage du moniteur.</translation>
    </message>
    <message>
        <source>I want to build accurate profile from measurement sheet</source>
        <translation>Je veux créer un profil précis à partir d&apos;une feuille de mesure.</translation>
    </message>
    <message>
        <source>Create monitor profile from measurements taken with a color meter.</source>
        <translation>Créer un profil moniteur à partir de mesures prises à l&apos;aide d&apos;un spectrométre.</translation>
    </message>
    <message>
        <source>IT8/CGATS.5 files (*.it? *.cgs *.IT? *.CGS);;All files (*.*)</source>
        <translation>Fichiers IT8/CGATS.5 (*.it? *.cgs *.IT? *.CGS);;Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <source>Measurement Sheet</source>
        <translation>Feuille de mesure</translation>
    </message>
    <message>
        <source>Monitor measurement sheet selector.</source>
        <translation>Sélecteur de feuille de mesure pour le moniteur.</translation>
    </message>
    <message>
        <source>Select a monitor measurement sheet to be used for creating a monitor profile.</source>
        <translation>Choisissez une feuille de mesure de moniteur à utiliser pour créer un profil moniteur.</translation>
    </message>
    <message>
        <source>Printer Profiler</source>
        <translation>Profil imprimante</translation>
    </message>
    <message>
        <source>Not yet implemented.</source>
        <translation>Pas encore implémenté.</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>*.icc; *.icm; *.ICC; *.ICM</source>
        <translation>*.icc; *.icm; *.ICC; *.ICM</translation>
    </message>
    <message>
        <source>Monitor profile</source>
        <translation>Profil moniteur</translation>
    </message>
    <message>
        <source>The monitor profile (used for softproofing)</source>
        <translation>Le profil moniteur (utilisé pour l&apos;épreuve logiciel)</translation>
    </message>
    <message>
        <source>The monitor profile (used for softproofing)</source>
        <comment>This is also passed to the profile checker tool.</comment>
        <translation>Le profil moniteur (utilisé pour l&apos;épreuve logiciel)</translation>
    </message>
    <message>
        <source>*.icc;*.icm;*.ICC;*.ICM</source>
        <translation>*.icc;*.icm;*.ICC;*.ICM</translation>
    </message>
    <message>
        <source>Input profile</source>
        <translation>Profil d&apos;entrée</translation>
    </message>
    <message>
        <source>The input profile (used for softproofing)</source>
        <translation>Le profil d&apos;entrée (utilisé pour l&apos;épreuve logiciel)</translation>
    </message>
    <message>
        <source>Color Manage display</source>
        <translation>Affichage en gestion de couleur</translation>
    </message>
    <message>
        <source>Use to enable soft proofing.</source>
        <translation>Utilisé pour permettre l&apos;épreuve logicielle.</translation>
    </message>
    <message>
        <source>To enable soft proofing.</source>
        <translation>Pour permettre l&apos;épreuve logicielle.</translation>
    </message>
    <message>
        <source>Install Reference File</source>
        <translation>Installer le fichier de référence</translation>
    </message>
    <message>
        <source>Safe &amp;frame (%):</source>
        <translation>Safe &amp;Rahmen (%):</translation>
    </message>
    <message>
        <source>The safe zone on patch picker</source>
        <translation>La zone protégée sur l&apos;échantilloneur</translation>
    </message>
    <message>
        <source>Output colorspace</source>
        <translation>Espace de couleur de sortie</translation>
    </message>
    <message>
        <source>Set what type of measurement file is created by the pick tool.</source>
        <translation>Choisir quel type de fichier de mesure est créé par l&apos;échantillonneur.</translation>
    </message>
    <message>
        <source>Set what type of measurement file is created by the pick tool.  In most cases use RGB.</source>
        <translation>Choisir quel type de fichier de mesure est créé par l&apos;échantillonneur. Dans la plupart des cas RVB.</translation>
    </message>
    <message>
        <source>&amp;RGB - Pick from image</source>
        <translation>&amp;RVB - Prendre de l&apos;image</translation>
    </message>
    <message>
        <source>Alt+R</source>
        <translation>Alt+R</translation>
    </message>
    <message>
        <source>&amp;Lab - Pick form image and apply input profile</source>
        <translation>&amp;Lab - Prendre de l&apos;image et appliquer le profil d&apos;entrée</translation>
    </message>
    <message>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <source>&amp;XYZ - Pick from image and apply input profile</source>
        <translation>&amp;XYZ - Prendre de l&apos;image et appliquer le profil d&apos;entrée</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Lab&amp;+XYZ - Pick from image, apply profile, convert (D50)</source>
        <translation>Lab&amp;+XYZ - Prendre de l&apos;image, appliquez le profil et convertit (D50)</translation>
    </message>
    <message>
        <source>Alt++</source>
        <translation>Alt++</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation>Caché</translation>
    </message>
    <message>
        <source>template</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <source>*.itx;*.ITX</source>
        <translation>*.itx;*.ITX</translation>
    </message>
    <message>
        <source>Pick template</source>
        <translation>Prendre modèle</translation>
    </message>
    <message>
        <source>Select a picker template for your target.</source>
        <translation>Choisissez un modèle d&apos;échantillonnage pour votre cible.</translation>
    </message>
    <message>
        <source></source>
        <comment>When the four corners have been selected the picker template will be placed and the measurement file will be created.  You can always adjust the location of the picker template by adjusting the selected corner location.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file parameter information.  This will affect how the profile is created.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The profiler message console contains information about the profile that is being created.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press this to bring up a file dialog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select your IT8.7 target from the list.  If it is not in the list then use the Reference File Installer to add it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IT8.7 target list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a monitor profiling method.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick RGB values directly from the image.  This is the default setting for most profiling operations.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick Lab values and apply the input profile.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick XYZ values and apply the input profile.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lab + XYZ - Pick from image, apply profile, convert (D50)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press this to bring up the Reference File Installer dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
